@@ -20,7 +20,18 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-all_attrs = ["TOXICITY", "SEVERE_TOXICITY", "IDENTITY_ATTACK", "INSULT", "PROFANITY", "THREAT", "TOXICITY_EXPERIMENTAL", "SEVERE_TOXICITY_EXPERIMENTAL", "IDENTITY_ATTACK_EXPERIMENTAL", "INSULT_EXPERIMENTAL", "PROFANITY_EXPERIMENTAL", "THREAT_EXPERIMENTAL", "SEXUALLY_EXPLICIT", "FLIRTATION", "ATTACK_ON_AUTHOR", "ATTACK_ON_COMMENTER", "INCOHERENT", "INFLAMMATORY", "LIKELY_TO_REJECT", "OBSCENE", "SPAM", "UNSUBSTANTIAL"]
+all_attrs = ["TOXICITY", "SEVERE_TOXICITY", "IDENTITY_ATTACK", 
+"INSULT", "PROFANITY", "THREAT", "TOXICITY_EXPERIMENTAL", 
+"SEVERE_TOXICITY_EXPERIMENTAL", "IDENTITY_ATTACK_EXPERIMENTAL", 
+"INSULT_EXPERIMENTAL", "PROFANITY_EXPERIMENTAL", 
+"THREAT_EXPERIMENTAL", "SEXUALLY_EXPLICIT", "FLIRTATION",
+"ATTACK_ON_AUTHOR", "ATTACK_ON_COMMENTER", "INCOHERENT", 
+"INFLAMMATORY", "LIKELY_TO_REJECT", "OBSCENE", "SPAM", 
+"UNSUBSTANTIAL"]
+
+all_prod_attrs = ["TOXICITY", "SEVERE_TOXICITY", "IDENTITY_ATTACK", "INSULT", "PROFANITY", "THREAT"]
+all_expr_attrs = ["TOXICITY_EXPERIMENTAL", "SEVERE_TOXICITY_EXPERIMENTAL", "IDENTITY_ATTACK_EXPERIMENTAL", "INSULT_EXPERIMENTAL", "PROFANITY_EXPERIMENTAL", "THREAT_EXPERIMENTAL", "SEXUALLY_EXPLICIT", "FLIRTATION"]
+all_newy_attrs = ["ATTACK_ON_AUTHOR", "ATTACK_ON_COMMENTER", "INCOHERENT", "INFLAMMATORY", "LIKELY_TO_REJECT", "OBSCENE", "SPAM", "UNSUBSTANTIAL"]
 class Attributes:
     class All:
         """
